# Procedure:	Toolbox
#
# Usage:	Toolbox
#
# Summary:	Creates the toolbox.
#

# Set the PXHOME environment variable
set PXHOME $env(PXHOME)
set FSLDIR $PXHOME/FSL
#set FSLVERSION [ exec cat ${FSLDIR}/etc/fslversion ]
set FSLVERSION 1.2a
# Added the following lines to define the current SPM report
# log filename.  -- Joe 03/28/01.
global spmReportLogFile
set spmReportLogFile "/tmp/MedxSpmReport_[ pid ].log"

proc Toolbox {w} {
    global toolbox MEDxModules
    global bitmapdir
    global PXHOME FSLDIR FSLVERSION
    global RunningWishes
    global RunningScripts spmReportLogFile

    set PLATFORM [exec $PXHOME/bin/platform]

    if [winfo exists $w] {
	wm deiconify $w
	raise $w
	return
    }

    set toolbox($w,opmode) none
    set toolbox($w,imode) none
    set toolbox($w,locktools) 0

    toplevel $w
    wm title $w "Toolbox"
    wm iconname $w "Toolbox"

    frame $w.f

    label $w.status -height 1 -relief sunken -bd 2 

    #------------- Icon Frame --------------

    frame $w.if -bd 3
    
    tixSelect $w.icons2d -radio true -allowzero false -labelside top \
	-orientation vertical \
	-label "Tools" \
	-options {
	    label.pady 3
	} \
	-command "Toolbox:ToolChanged $w"

    tixBalloon $w.bhelp -state status -statusbar $w.status

    set bsize 20

    $w.icons2d add point -bitmap @$bitmapdir/mpx-point \
	 -width $bsize -height $bsize
    $w.icons2d add pencil -bitmap @$bitmapdir/mpx-pencil \
	-width $bsize -height $bsize
    $w.icons2d add rectangle -bitmap @$bitmapdir/mpx-rect \
	-width $bsize -height $bsize
    $w.icons2d add ellipse -bitmap @$bitmapdir/mpx-circle \
	-width $bsize -height $bsize
    $w.icons2d add text	-bitmap @$bitmapdir/mpx-text \
	-width $bsize -height $bsize
    $w.icons2d add angle -bitmap @$bitmapdir/mpx-angle \
	-width $bsize -height $bsize
    $w.icons2d add line	-bitmap @$bitmapdir/mpx-line \
	-width $bsize -height $bsize
    $w.icons2d add arrow -bitmap @$bitmapdir/mpx-arrow \
	-width $bsize -height $bsize
    $w.icons2d add bitmap -bitmap @$bitmapdir/mpx-bitmapedit \
	-width $bsize -height $bsize
    $w.icons2d add polygon -bitmap @$bitmapdir/mpx-poly \
	-width $bsize -height $bsize
    $w.icons2d add arbitrary -bitmap @$bitmapdir/mpx-arbitrary \
	-width $bsize -height $bsize
    $w.icons2d add button -bitmap @$bitmapdir/mpx-button \
	-width $bsize -height $bsize
    $w.icons2d add marker -bitmap @$bitmapdir/mpx-marker \
	-width $bsize -height $bsize
    $w.icons2d add edge -bitmap @$bitmapdir/mpx-edge \
	-width $bsize -height $bsize
    $w.icons2d add erase -bitmap @$bitmapdir/mpx-eraser \
	-width $bsize -height $bsize
    $w.icons2d add pixelreport -bitmap @$bitmapdir/pixelreport.xbm \
	-width $bsize -height $bsize
    $w.icons2d add rotate -bitmap @$bitmapdir/mpx-rotate \
	-width $bsize -height $bsize 



    $w.bhelp bind [$w.icons2d subwidget point] \
	-msg "Pointer Mode"
    $w.bhelp bind [$w.icons2d subwidget pencil] \
	-msg "Pencil Mode"
    $w.bhelp bind [$w.icons2d subwidget rectangle] \
	-msg "Rectangle Mode"
    $w.bhelp bind [$w.icons2d subwidget ellipse] \
	-msg "Ellipse Mode"
    $w.bhelp bind [$w.icons2d subwidget text] \
	-msg "Text Mode"
   $w.bhelp bind [$w.icons2d subwidget angle] \
	-msg "Angle Mode"
   $w.bhelp bind [$w.icons2d subwidget line] \
	-msg "Line Mode"
   $w.bhelp bind [$w.icons2d subwidget arrow] \
	-msg "Arrow Mode"
   $w.bhelp bind [$w.icons2d subwidget bitmap] \
	-msg "Bitmap Mode"
   $w.bhelp bind [$w.icons2d subwidget polygon] \
	-msg "Polygon Mode"
   $w.bhelp bind [$w.icons2d subwidget arbitrary] \
	-msg "Edit Polygon Graphics"
   $w.bhelp bind [$w.icons2d subwidget button] \
	-msg "Button Mode"
   $w.bhelp bind [$w.icons2d subwidget marker] \
	-msg "Marker Mode"
   $w.bhelp bind [$w.icons2d subwidget edge] \
	-msg "Edge Follower Mode"
   $w.bhelp bind [$w.icons2d subwidget erase] \
	-msg "Eraser Mode"
   $w.bhelp bind [$w.icons2d subwidget pixelreport] \
	-msg "Pixel Reporting Mode"
   $w.bhelp bind [$w.icons2d subwidget rotate] \
	-msg "Rotate Mode"

    #----

    tixSelect $w.icons3d -radio true -allowzero false -labelside top \
	-orientation vertical \
	-label "Tools" \
	-options {
	    label.pady 3
	} \
	-command "Toolbox:ToolChanged $w"

    $w.icons3d add point -bitmap @$bitmapdir/mpx-point \
	-width $bsize -height $bsize
    $w.icons3d add box -bitmap @$bitmapdir/mpx-box \
	-width $bsize -height $bsize
    $w.icons3d add ellipsoid -bitmap @$bitmapdir/mpx-ellipsoid \
	-width $bsize -height $bsize
    $w.icons3d add line3d -bitmap @$bitmapdir/mpx-line \
	-width $bsize -height $bsize
    $w.icons3d add angle3d -bitmap @$bitmapdir/mpx-angle \
	-width $bsize -height $bsize
    $w.icons3d add bitmap -bitmap @$bitmapdir/mpx-bitmapedit \
	-width $bsize -height $bsize
    $w.icons3d add contour -bitmap @$bitmapdir/mpx-contouredit \
	-width $bsize -height $bsize
    $w.icons3d add marker3d -bitmap @$bitmapdir/mpx-marker \
	-width $bsize -height $bsize
    $w.icons3d add pixelreport -bitmap @$bitmapdir/pixelreport.xbm \
	-width $bsize -height $bsize

    $w.bhelp bind [$w.icons3d subwidget point] \
	-msg "Pointer Mode"
    $w.bhelp bind [$w.icons3d subwidget box] \
	-msg "Box Mode"
    $w.bhelp bind [$w.icons3d subwidget ellipsoid] \
	-msg "Ellipsoid Mode"
    $w.bhelp bind [$w.icons3d subwidget line3d] \
	-msg "3D Line Mode"
    $w.bhelp bind [$w.icons3d subwidget angle3d] \
	-msg "3D Angle Mode"
    $w.bhelp bind [$w.icons3d subwidget bitmap] \
	-msg "3D Bitmap Mode"
    $w.bhelp bind [$w.icons3d subwidget contour] \
	-msg "Edit Contour Mode"
    $w.bhelp bind [$w.icons3d subwidget marker3d] \
	-msg "3D Marker Mode"
    $w.bhelp bind [$w.icons3d subwidget pixelreport] \
	-msg "Pixel Reporting Mode"


    pack $w.icons2d -in $w.if 

    #------------- Holding Frame --------------

    frame $w.hf 

    #------------- Menu Frame --------------

    frame $w.mf -bd 3

    label $w.mf.l -text "Operation Menus"
    button $w.algebraic -text Algebraic -width 12 -pady 2 \
	-relief raised -command "Toolbox:placemenu $w algebraic"
    button $w.simulate -text Simulators -width 12 -pady 2 \
        -relief raised -command "Toolbox:placemenu $w simulate"

    button $w.conversion -text Conversion -width 12 -pady 2 \
	-relief raised -command "Toolbox:placemenu $w conversion"
    button $w.filtering -text Filtering -width 12 -pady 2 \
	-relief raised -command "Toolbox:placemenu $w filtering"
    button $w.measurement -text Measurement -width 12 -pady 2 \
	-relief raised -command "Toolbox:placemenu $w measurement"
    button $w.registration -text Registration -width 12 -pady 2 \
	-relief raised -command "Toolbox:placemenu $w registration"
    button $w.segmentation -text Segmentation -width 12 -pady 2 \
	-relief raised -command "Toolbox:placemenu $w segmentation"
    button $w.transformation -text Transformation -width 12 -pady 2 \
	-relief raised -command "Toolbox:placemenu $w transformation"
    button $w.fusion -text Fusion -width 12 -pady 2 \
	-relief raised -command "Toolbox:placemenu $w fusion"
    button $w.functional -text "Functional" -width 12 -pady 2 \
	-relief raised -command "Toolbox:placemenu $w functional"
    button $w.spm -text "SPM Modules" -width 12 -pady 2 \
	-relief raised -command "Toolbox:placemenu $w spm"
    button $w.fsl -text "FSL $FSLVERSION" -width 12 -pady 2 \
	-relief raised -command "Toolbox:placemenu $w fsl"
    button $w.vol -text "Volumetric" -width 12 -pady 2 \
	-relief raised -command "Toolbox:placemenu $w vol"


    #------------- Pack Menu Frame --------------

    pack $w.mf.l $w.algebraic  $w.simulate $w.conversion $w.filtering \
	$w.measurement $w.registration $w.segmentation $w.transformation \
	$w.fusion $w.functional $w.spm $w.fsl $w.vol \
	-in $w.mf -side top

    #------------------ Algebraic (ie., Image Math) Menu --------------------

    set m [menu $w.algebraic.menu -tearoffcommand "Toolbox:tearoff Algebraic"]
    $m add command -label "Complex Math..." \
	-command {Message:PostDialog .complexmath}
    $m add command -label "Sum Images..." \
	-command {Message:PostDialog .sumimages}
    
    #------------------ Simulator Menu --------------------

    set m [menu $w.simulate.menu -tearoffcommand "Toolbox:tearoff Simulate"]

    $m add command -label "Generate Noise/Function..." \
        -command {Message:PostDialog .generate}
    $m add command -label "4D Data Simulator... " \
        -command {set status [catch {eval exec $PXHOME/bin/tixwish -f $PXHOME/ui/dialogs/simulator.tcl &} junki]; 
            lappend RunningWishes(pids) $junki;
            lappend RunningScripts(scriptpid) $junki
        }
    
    #------------------ Filtering Menu --------------------

    set m [menu $w.filtering.menu \
	-tearoffcommand "Toolbox:tearoff Filtering"]
    $m add command -label "Frequency Domain..." \
	-command {Message:PostDialog .frequencydomain}
    $m add command -label "Neighborhood Operations..." \
	-command {Message:PostDialog .neighbor}
    $m add command -label "Morphology..." \
	-command {Message:PostDialog .morphology}
    $m add separator
    $m add command -label "Map Pixels..." \
	-command {Message:PostDialog .mappixels}
    $m add command -label "Equalization..." \
	-command {Message:PostDialog .equalization}

    #------------------ Conversion Menu --------------------

    set m [menu $w.conversion.menu \
	-tearoffcommand "Toolbox:tearoff Conversion"]
    $m add command -label "Data Encoding..." \
	-command {Message:PostDialog .convertdata}
    $m add command -label "Compose Volume" \
	-command {Message:InvokeFunction ComposeVolume}
    $m add command -label "Color Conversion..." \
	-command {Message:PostDialog .colorconv}
    $m add command -label "Compose Triband..." \
	-command {Message:PostDialog .colorcompose}
    $m add command -label "24 bit to 8 bit" \
	-command {Message:InvokeFunction Convert24to8}

    #------------------ Measurement Menu --------------------

    set m [menu $w.measurement.menu \
	-tearoffcommand "Toolbox:tearoff Measurement"]
    $m add command -label "Histogram..." \
	-command {Message:PostDialog .histogram}
    $m add command -label "Statistics..." \
	-command {Message:PostDialog .statistics}
    $m add command -label "ROI Template Utilities..." \
	-command {Message:PostDialog .roitemplate}
    $m add command -label "Time Stamp Entry..." \
	-command {Message:PostDialog .timestamp}
    $m add command -label "Time Activity Curve..." \
	-command {Message:PostDialog .tac}
#    $m add command -label "Spatial Smoothness..." \
#	-command {Message:PostDialog .smoothness}
    $m add separator
    $m add command -label "Line Profile..." \
	-command {Message:PostDialog .lineprofile}
    $m add separator
    $m add cascade -label "Gnu Plot" \
	-menu $m.gnuplot
     menu $m.gnuplot
    $m.gnuplot add command -label "Create" \
	-command {Message:InvokeFunction GnuplotThisVector}
    $m.gnuplot add command -label "Clear" \
	-command {Message:InvokeFunction ClearGnuplot}
    $m.gnuplot add command -label "Print" \
	-command {Message:InvokeFunction GnuplotPostscript}

    #------------------ Registration Menu --------------------

    set m [menu $w.registration.menu \
	-tearoffcommand "Toolbox:tearoff Registration"]
    $m add command -label "Surface..." \
	-command {Message:PostDialog .surfaceregister}
    $m add command -label "AIR..." \
	-command {Message:PostDialog .air}
    $m add command -label "Talairach Atlas..." \
	-command {Message:PostDialog .talairach}
    $m add command -label "Warp (2D)..." \
	-command {Message:PostDialog .warp}

    #------------------ Segmentation Menu --------------------

    set m [menu $w.segmentation.menu \
	-tearoffcommand "Toolbox:tearoff Segmentation"]
    $m add command -label "Thresholding..." \
	-command {Message:PostDialog .threshold}
    $m add command -label "Clustering..." \
	-command {Message:PostDialog .cluster}
    $m add command -label "Region Growing..." \
	-command {Message:PostDialog .regiongrow}
    $m add command -label "Interactive Segmentation" \
	-command "Toolbox:skullstrip"

    #------------------ Transformation Menu --------------------

    set m [menu $w.transformation.menu \
	-tearoffcommand "Toolbox:tearoff Transformation"]
    $m add command -label "Spatial (2D)..." \
	-command {Message:PostDialog .spatial2d}
    $m add command -label "Resample..." \
	-command {Message:PostDialog .resample} \
	-state disabled
    $m add command -label "Flip Volume..." \
        -command {set status [catch {eval exec $PXHOME/bin/tixwish \
	   -f ${PXHOME}/ui/dialogs/flip.tcl &} junk];
	   lappend RunningWishes(pids) $junk;
	   lappend RunningScripts(scriptpid) $junk
	} \
	-state disabled
    $m add separator
    $m add command -label "FFT" \
	-command {Message:InvokeFunction ForwardFFT}
    $m add command -label "Inverse FFT" \
	-command {Message:InvokeFunction InverseFFT}
    $m add separator
    $m add command -label "Wavelet Transform..." \
	-command {Message:PostDialog .wavelet}
    $m add separator
    $m add cascade -label "Shadow Transform" \
	-menu $m.shadowtransform
     menu $m.shadowtransform
    $m.shadowtransform add command -label "Save..." \
	-command {Message:PostDialog .saveshadowtransform}
    $m.shadowtransform add command -label "Apply..." \
	-command {Message:PostDialog .applyshadowtransform}

    #------------------ Fusion Menu --------------------

    set m [menu $w.fusion.menu -tearoffcommand "Toolbox:tearoff Fusion"]
    $m add command -label "Colorwash..." \
	-command {Message:PostDialog .colorwash}
    $m add command -label "Blend Images..." \
	-command {Message:PostDialog .blend}

    #------------------ Functional Menu --------------------

    set m [menu $w.functional.menu -tearoffcommand "Toolbox:tearoff Functional"]
    $m add command -label "Define Paradigm..." \
	-command {Message:PostDialog .paradigmedit}
#    $m add cascade -label "Define Paradigm..." \
#	-menu $m.paradigm
#     menu $m.paradigm
#    $m.paradigm add command -label "Create/Edit..." \
#	-command {Message:PostDialog .paradigmedit}
#    $m.paradigm add command -label "Apply..." \
#	-command {Message:PostDialog .applyparadigm}

# Alternative place to initiate 4D data simulator - also appears in new 'Simulate' menu
#    $m add command -label "4D Data Simulator... " \
#	-command {set status [catch {eval exec $PXHOME/bin/tixwish -f $PXHOME/ui/dialogs/simulator.tcl &} junkf]; 
#	    lappend RunningWishes(pids) $junkf;
#	    lappend RunningScripts(scriptpid) $junkf
#	}

    $m add command -label "Time Series..." \
	-command {Message:PostDialog .timeseries}
    $m add cascade -label "Motion Detection" \
	-menu $m.motiondetect
     menu $m.motiondetect
    $m.motiondetect add command -label "Center of Intensity..." \
	-command {Message:PostDialog .centerofgravity}
    $m.motiondetect add command -label "Animation..." \
	-command {Message:PostDialog .animation}
    $m add command -label "Motion Correction..." \
	-command {Message:PostDialog .motioncorrection}
    $m add command -label "Filtering..." \
	-command {Message:PostDialog .filtering}
    $m add command -label "Intensity Normalization..." \
	-command {Message:PostDialog .intensitynormalization}

    $m add separator

    $m add command -label "Correlation Analysis..." \
	-command {Message:PostDialog .cor}
#    if {[lsearch -exact $MEDxModules "perfusion"] < 0} {
#	$m add command -label "Perfusion Analysis..." -state disabled
#    } else {
#	$m add command -label "Perfusion Analysis..." \
#	    -command {Message:PostDialog .perfusion}
#    }
##  MR Parameter estimation moved to toolbox by EDM 3-15-01
#    $m add command -label "MR Parameter Estimation... " \
#	-command {set status [catch {eval exec $PXHOME/bin/tixwish -f $PXHOME/ui/dialogs/mrparams.tcl &} junkm]; 
#	    lappend RunningWishes(pids) $junkm;
#	    lappend RunningScripts(scriptpid) $junkm
#	}

    $m add command -label "Sinusoidal Regression..." \
	-command {Message:PostDialog .sinusoid}
#    $m add command -label "PLS Analsyis..." \
#	-command {Message:PostDialog .pls}
    $m add command -label "Group Statistics..." \
	-command {Message:PostDialog .groupstatistics}

    $m add separator

    $m add command -label "Local Min/Max..." \
	-command {Message:PostDialog .findlocalminmax}
    $m add command -label "Final Significance..." \
	-command {Message:PostDialog .finalsignificance}
#    $m add command -label "Cluster Detection..." \
#	-command {Message:PostDialog .clusteranalysis}
#    $m add command -label "Critical Threshold..." \
#	-command {Message:PostDialog .criticalthreshold}

    # Check if this is a SUN or SGI workstation
    if {$PLATFORM == "SPARC_2" || $PLATFORM == "SGI_5"} {
	$m add command -label "Talairach Daemon Interface..." \
		-command {Message:PostDialog .talairachdaemon}
    }

    $m add command -label "Render Statistics..." \
	-command {Message:PostDialog .renderstatistics}
    $m add command -label "Regional Analysis..." \
	-command {Message:InvokeFunction TimeSeriesRegionGraphic}
    $m add cascade -label "Temporal Display" \
	-menu $m.temporaldisplay

    $m add separator
# Alternative place to initiate 4D data simulator - also appears in new 'Simulate' menu
    $m add command -label "4D Data Simulator... " \
	-command {set status [catch {eval exec $PXHOME/bin/tixwish -f $PXHOME/ui/dialogs/simulator.tcl &} junkf]; 
	    lappend RunningWishes(pids) $junkf;
	    lappend RunningScripts(scriptpid) $junkf
	}
    if {[lsearch -exact $MEDxModules "perfusion"] < 0} {
	$m add command -label "Perfusion Analysis..." -state disabled
    } else {
	$m add command -label "Perfusion Analysis..." \
	    -command {Message:PostDialog .perfusion}
    }
#  MR Parameter estimation moved to toolbox by EDM 3-15-01
    $m add command -label "MR Parameter Estimation... " \
	-command {set status [catch {eval exec $PXHOME/bin/tixwish -f $PXHOME/ui/dialogs/mrparams.tcl &} junkm]; 
	    lappend RunningWishes(pids) $junkm;
	    lappend RunningScripts(scriptpid) $junkm
	}


    menu $m.temporaldisplay
    if {[lsearch -exact $MEDxModules "perfusion"] < 0} {
	$m.temporaldisplay add command -label "Enable" \
	    -command {Message:InvokeFunction ReportTimeVoxels "mode? true"}
	$m.temporaldisplay add command -label "Disable" \
	    -command {Message:InvokeFunction ReportTimeVoxels "mode? false"}
    } else {
	$m.temporaldisplay add command -label "Functional" \
	    -command {Message:InvokeFunction ReportTimeVoxels "mode? true"}
	$m.temporaldisplay add command -label "Perfusion" \
	    -command {Message:InvokeFunction SPMReportTimeVoxels \
		"mode? true /Type /Perfusion"}
	$m.temporaldisplay add command -label "Disable" \
	    -command {Message:InvokeFunction ReportTimeVoxels "mode? false"}
    }

    #------------------ SPM Menu --------------------
#TALIN changed some of the SPM menu related items
    set m [menu $w.spm.menu -tearoffcommand "Toolbox:tearoff {SPM Modules}"]
    $m add cascade -label "SPM96" \
	-menu $m.spm96
    menu $m.spm96
    $m.spm96 add command -label "About SPM... " \
        -command {Message:PostDialog .spm_about}
    $m.spm96 add command -label "Realign... " \
        -command {Message:PostDialog .spm_realign}
    $m.spm96 add command -label "Coregister... " \
        -command {Message:PostDialog .spm_coreg}
#    $m.spm96 add command -label "Coregister Intermodality... " \
#        -command {Message:PostDialog .spm_coregbetween} -state disabled
    $m.spm96 add command -label "Spatial Normalize... " \
        -command {Message:PostDialog .spm_spatialnorm}
    $m.spm96 add command -label "Smoothing... " \
        -command {Message:PostDialog .spm_smooth}
    $m.spm96 add command -label "Statistics... " \
        -command {Message:PostDialog .spm_statistics}
    $m.spm96 add command -label "Rethreshold... " \
        -command {Message:PostDialog .spm_statresults}
    $m.spm96 add command -label "Conjunction Analysis... " \
        -command {Message:PostDialog .spm_conjunct}
    $m.spm96 add command -label "Eigen Image Analysis... " \
        -command {Message:PostDialog .spm_eigenimage}
    $m.spm96 add command -label "Tissue Segment... " \
        -command {Message:PostDialog .spm_segment}

    $m.spm96 add cascade -label "Plotting" \
	-menu $m.spm96.spmplotting
     menu $m.spm96.spmplotting
    $m.spm96.spmplotting add command -label "Conditions" \
	-command {Message:InvokeFunction SPMReportTimeVoxels \
		"mode? true /Type /Conditions"}
    $m.spm96.spmplotting add command -label "Scans" \
	-command {Message:InvokeFunction SPMReportTimeVoxels \
		"mode? true /Type /Scans"}
    $m.spm96.spmplotting add command -label "Covariates..." \
	-command {Message:PostDialog .spm_covplot}
    $m.spm96.spmplotting add command -label "Disable" \
	-command {Message:InvokeFunction SPMReportTimeVoxels \
		"mode? false"}

    # Invoke SPM99 directly with an exec, not via a spawned-off tixwish
    # or spawned-off Bourne shell, so that it dies gracefully when
    # MEDx is killed via the RunningWishes/RunningScripts mechanism.
    # Otherwise, what gets killed is the tixwish or the Bourne shell,
    # NOT SPM99.  Use tail/spmReportLogFile mechanism to display SPM99
    # text to screen.  -- Joe 03/28/01.
    $m add command -label "SPM99" \
	-command { \
		global spmReportLogFile;
		set status [ catch { eval exec \
		    $PXHOME/SPM99/$PLATFORM/voidspm \
			> $spmReportLogFile & } voidspmPID ];
		set tailpid [ exec tail -f $spmReportLogFile & ];
		lappend RunningWishes(pids) $voidspmPID;
		lappend RunningScripts(scriptpid) $voidspmPID;
		lappend RunningWishes(pids) $tailpid;
		lappend RunningScripts(scriptpid) $tailpid
	}


    #------------------ FSL Menu --------------------
    set m [menu $w.fsl.menu -tearoffcommand "Toolbox:tearoff FSL"]
    $m add cascade -label "Structural Analysis " \
	-menu $m.structanalysis
     menu $m.structanalysis

    $m.structanalysis add command -label "BET Brain Extraction " \
	-command {Message:PostDialog .betoptions}
# The following construction doesn't work for BET.
#    if { [ file exists ${PXHOME}/ui/dialogs/bet.tcl ] } {
#    	   $m.structanalysis add command -label "BET " \
#	      -command {set status [catch {eval exec $PXHOME/bin/tixwish \
#			-f ${PXHOME}/ui/dialogs/bet.tcl dummyGuiFlag &} junk];
#			lappend RunningWishes(pids) $junk;
#			lappend RunningScripts(scriptpid) $junk
#		}
#     }
    $m.structanalysis add command -label "FLIRT Linear Registration " \
	-command {Message:PostDialog .flirtregister}
    $m.structanalysis add command -label "SUSAN Nonlinear Noise Reduction... " \
	-command {Message:PostDialog .susannoisered}
    $m add cascade -label "FMRI Analysis " \
	-menu $m.featdetect
    menu $m.featdetect
    if { [ file exists ${FSLDIR}/tcl/feat.tcl ] } {
    	   $m.featdetect add command -label "FEAT " \
	      -command {set status [catch {eval exec $PXHOME/bin/tixwish \
			-f ${FSLDIR}/tcl/feat.tcl &} junk];
			lappend RunningWishes(pids) $junk;
			lappend RunningScripts(scriptpid) $junk
		}
     }
    if { [ file exists ${FSLDIR}/tcl/irva.tcl ] } {
    	   $m.featdetect add command -label "Inter-Repetition Variance Analysis" \
	      -command {set status [catch {eval exec $PXHOME/bin/tixwish \
			-f ${FSLDIR}/tcl/irva.tcl &} junk];
			lappend RunningWishes(pids) $junk;
			lappend RunningScripts(scriptpid) $junk
		}
     }
    $m.featdetect add command -label "Statistics Colour Rendering " \
	-command {Message:PostDialog .featrender}
    $m.featdetect add command -label "Signal-to-Noise Ratio " \
	-command {Message:PostDialog .featsnr}
    $m add cascade -label "Misc Utilties " \
	-menu $m.miscutilities 
     menu $m.miscutilities 

    $m.miscutilities add command -label "Make Image Isometric " \
	    -command {set USER $env(USER); set status [catch {exec sh -ce "${FSLDIR}/tcl/runscript.sh 0  ${FSLDIR}/tcl/volume_run.tcl ${FSLDIR}/tcl/iso.tcl makeiso \"0\"" &} junk]}
    if { [ file exists ${FSLDIR}/tcl/concat_transforms.tcl ] } {
    	   $m.miscutilities add command -label "Concat Transforms " \
	      -command {set status [catch {eval exec $PXHOME/bin/tixwish \
			-f ${FSLDIR}/tcl/concat_transforms.tcl &} junk];
			lappend RunningWishes(pids) $junk;
			lappend RunningScripts(scriptpid) $junk
		}
     }
    $m.miscutilities add command -label "Set Origin " \
	-command {Message:PostDialog .copyorigin}
    if { [ file exists ${PXHOME}/ui/dialogs/save_folder.tcl ] } {
    	   $m.miscutilities add command -label "Delayed Folder Saving " \
	      -command {set status [catch {eval exec $PXHOME/bin/tixwish \
			-f ${PXHOME}/ui/dialogs/save_folder.tcl &} junk];
			lappend RunningWishes(pids) $junk;
			lappend RunningScripts(scriptpid) $junk
		}
    }
#    $m.miscutilities add command -label "Enhance Display " \
#	-command {Message:PostDialog .posvoxel}

    $m.miscutilities add separator
    if { [ file exists ${FSLDIR}/tcl/median.tcl ] } {
    	   $m.miscutilities add command -label "Group Median " \
	      -command {set status [catch {eval exec $PXHOME/bin/tixwish \
			-f ${FSLDIR}/tcl/median.tcl &} junk];
			lappend RunningWishes(pids) $junk;
			lappend RunningScripts(scriptpid) $junk
		}
     }
    $m.miscutilities add command -label "Group Do (Generic Operation) " \
	    -command "FmribWebHelp file: ${FSLDIR}/doc/util/groupdo_index.html"
    if { [ file exists ${FSLDIR}/tcl/scatter.tcl ] } {
    	   $m.miscutilities add command -label "Scatter Plot from 2 Images " \
	      -command {set status [catch {eval exec $PXHOME/bin/tixwish \
			-f ${FSLDIR}/tcl/scatter.tcl &} junk];
			lappend RunningWishes(pids) $junk;
			lappend RunningScripts(scriptpid) $junk
		}
     }

    $m.miscutilities add separator
    if { [ file exists ${FSLDIR}/tcl/cut_corner.tcl ] } {
    	   $m.miscutilities add command -label "Cut 3D Corner " \
	      -command {set status [catch {eval exec $PXHOME/bin/tixwish \
			-f ${FSLDIR}/tcl/cut_corner.tcl &} junk];
			lappend RunningWishes(pids) $junk;
			lappend RunningScripts(scriptpid) $junk
		}
     }
    $m.miscutilities add command -label "Rendering Animation " \
	    -command "FmribWebHelp file: ${FSLDIR}/doc/util/run_anim.html"
    if { [ file exists ${FSLDIR}/tcl/rolling_display.tcl ] } {
    	   $m.miscutilities add command -label "Rolling Display " \
	      -command {set status [catch {eval exec $PXHOME/bin/tixwish \
			-f ${FSLDIR}/tcl/rolling_display.tcl &} junk];
			lappend RunningWishes(pids) $junk;
			lappend RunningScripts(scriptpid) $junk
		}
     }
    $m add separator
    $m add command -label "Help " \
	-command { source ${PXHOME}/ui/dialogs/webhelp.tcl ; FmribWebHelp file: ${FSLDIR}/doc/fslmedxmenu.html }

    #------------------ Volumetric Menu --------------------
    set m [menu $w.vol.menu -tearoffcommand "Toolbox:tearoff Volumetric"]
    $m add command -label "Analysis of Brain Lesions... " \
        -command {set status [catch {eval exec $PXHOME/bin/tixwish \
                   -f ${PXHOME}/ui/dialogs/able.tcl &} junk];
                   lappend RunningWishes(pids) $junk;
                   lappend RunningScripts(scriptpid) $junk
                 }
    # Check if this is a SUN or SGI workstation
    if {$PLATFORM == "SPARC_2" || $PLATFORM == "SGI_5"} {
        $m add command -label "Talairach Daemon Interface..." \
                -command {Message:PostDialog .talairachdaemon}
    }


    #------------- Viewer Mode Frame --------------

    frame $w.vf -bd 3

    label $w.vf.l -text "Dimensionality" -width 18 -anchor center
    set bitmapfn "my-2d"
    button $w.dimensions -bitmap @$bitmapdir/$bitmapfn \
        -command "Message:InvokeFunction NextOperatingMode"

    $w.bhelp bind $w.dimensions \
	-msg "Set Dimensionality"

    #----

    pack $w.vf.l $w.dimensions -in $w.vf -side top -padx 3 

    #------------- Button Frame --------------

    frame $w.btns
    frame $w.btns.b -relief raised -borderwidth 1
    button $w.cancel -command "Toolbox:destroy $w" \
	-text "Close" -width 5
    bind $w.cancel <Return> {
	Toolbox:destroy [winfo toplevel %W]}
    button $w.help   -command "WebHelp dialogs/Toolbox" \
	-text "Help" -width 5

    #------------- Pack Button Frame --------------

    pack $w.btns.b -fill x -padx 3 -pady 3
    pack $w.cancel $w.help -in $w.btns.b \
	    -side left -expand yes -padx 5 -pady 10 -fill y

    #------------- Flip Frame --------------

    frame $w.ff -bd 3

    set bsize 22

    label $w.ff.l -text "Graphic Transforms"
    frame $w.ff.f 
    button $w.fliplr -bitmap @$bitmapdir/mpx-fliplr \
        -command "Message:InvokeFunction FlipGraphicLR" \
	-width $bsize -height $bsize -highlightthickness 0
    button $w.fliptb -bitmap @$bitmapdir/mpx-fliptb \
        -command "Message:InvokeFunction FlipGraphicTB" \
	-width $bsize -height $bsize -highlightthickness 0
    button $w.reflect -bitmap @$bitmapdir/mpx-reflect \
        -command "Message:InvokeFunction ReflectGraphic" \
	-width $bsize -height $bsize -highlightthickness 0

    $w.bhelp bind $w.fliplr \
	-msg "Flip Left to Right"
    $w.bhelp bind $w.fliptb \
	-msg "Flip Top to Bottom"
    $w.bhelp bind $w.reflect \
	-msg "Flip About a Line"


    #----

    pack $w.ff.l $w.ff.f -side top -padx 3 
    pack $w.fliplr $w.fliptb $w.reflect -in $w.ff.f -side left \
	-pady 3

    #-------------------- Lock tools ----------------

    frame $w.lf -bd 3
    set bsize 22

    label $w.lf.l -text "Lock Graphic Tools"

    set lockbitmap "mpx-unlock"
    button $w.locktools -bitmap @$bitmapdir/$lockbitmap \
	-width $bsize -height $bsize -highlightthickness 0 \
	-command "Toolbox:LockChanged $w"

    $w.bhelp bind $w.locktools \
	-msg "Lock graphic tools"

    pack $w.lf.l $w.locktools -in $w.lf -side top -padx 3

    #------------- Focus --------------

    bind $w.help <Tab> {focus [winfo toplevel %W].algebraic
	break}
    bind $w.functional <Tab> {focus [winfo toplevel %W].dimensions
	break}
    bind $w.dimensions <Tab> {focus [winfo toplevel %W].cancel
	break}
    bind $w.fliplr <Tab> {focus [winfo toplevel %W].dimensions
	break}


    bind $w <Control-c> {
	destroy [winfo toplevel %W]
    }

    pack $w.f -side top -expand yes -fill both 
    pack $w.status -side top -fill both -padx 3 -pady 3
    pack $w.btns -side top  -fill both 
    pack $w.if $w.hf -in $w.f -side left -expand yes -fill both
    pack $w.mf $w.vf $w.lf $w.ff -in $w.hf -side top -expand yes -fill both

    Message:ExpressPropertyInterest Toolbox:Update $w CurrentShell \
	{ InteractiveMode OperatingMode LockTools? }
    Message:DialogPosted $w
}

proc Toolbox:LockChanged { w } {
    global toolbox

    if { $toolbox($w,locktools) == 1 } {
	set toolbox($w,locktools) 0
	set props "LockTools? false"
    } else {
	set toolbox($w,locktools) 1
	set props "LockTools? true"
    }
	
    Message:SetProperties CurrentShell "$props"
}

proc Toolbox:ToolChanged { w button value } {

    if { $value ==  0 } return
    switch -exact $button {
	point       { set p PointTool }
	pencil      { set p PencilTool }
	rectangle   { set p RectangleTool }
	ellipse     { set p CircleTool }
	text        { set p TextTool }
	line        { set p LineTool }
	angle       { set p AngleTool }
	arrow       { set p ArrowTool }
	bitmap      { set p BitmapEditTool }
	polygon     { set p PolyTool }
	arbitrary   { set p PolyEditTool }
	button      { set p ButtonTool }
	marker      { set p MarkerTool }
	edge        { set p EdgeTool }
	erase	    { set p EraserTool }
	pixelreport { set p PixelTool }
	rotate      { set p RotateGraphicTool }

	box         { set p BoxTool }
	ellipsoid   { set p EllipsoidTool }
	contour     { set p Poly3DTool }
	marker3d    { set p Marker3DTool }
	line3d      { set p Line3DTool }
	angle3d     { set p Angle3DTool }
	default     { set p PointTool }
    }

    Message:SetProperties CurrentShell "InteractiveMode $p"
}


proc Toolbox:placemenu {w menu} {
    global PXHOME PLATFORM
    global toolbox MEDxModules

    tk_popup $w.$menu.menu \
	[expr [winfo x $w] + [winfo x $w.$menu]  + 110] \
	[expr [winfo y $w] + [winfo y $w.$menu]]
}


 
# Procedure:	Toolbox:tearoff
#
# Usage:	Toolbox:tearoff title w newmenu
#

# Summary:	title the tearoff and add it to a list
#
proc Toolbox:tearoff {title w newmenu} {
    global toolbox

    wm title $newmenu $title
    lappend toolbox($w,tearoffs) $newmenu
}

# Procedure:	Toolbox:menupdate
#
# Usage:	Toolbox:menupdate w entry cmd
#
# Summary:	Go through the list of tearoffs for this menu and
#		change the entry according to the command given.
#		Also applies the command the entry in the original
#		menu.
#
proc Toolbox:menupdate {w entry cmd} {
    global toolbox

    # Just do the menu if no tearoffs have been made yet
    if {[lsearch [array names toolbox] "$w,tearoffs"] == -1} {
	if {$cmd != ""} {
	    set index [$w index $entry]
	    uplevel #0 $w "entryconfigure $index" $cmd
	}
	return
    }

    # Update our list - some tearoffs may have
    #	been blown away
    set current ""
    foreach tearoff $toolbox($w,tearoffs) {
	if [winfo exists $tearoff] {
	    lappend current $tearoff
	}
    }
    set toolbox($w,tearoffs) $current

    # Now apply the command to everybody
    if {$cmd != ""} {
	set index [$w index $entry]
	uplevel #0 $w "entryconfigure $index" $cmd
	foreach tearoff $toolbox($w,tearoffs) {
	    set index [$tearoff index $entry]
	    uplevel #0 $tearoff "entryconfigure $index" $cmd
	}
    }
}


proc Toolbox:destroy {w} {
    destroy $w
    
    Message:DialogUnposted $w
    Message:CancelPropertyInterest Toolbox:Update $w
}

# Procedure:	Toolbox:update
#
# Usage:	Toolbox:update widget
#
# Summary:	
#
proc Toolbox:Update {w target prop} {
    global toolbox
    global bitmapdir

    set toolbox($w,locktools) [ PxGet $prop LockTools? \
				       $toolbox($w,locktools) ]

    if { $toolbox($w,locktools) == 1 } {
	set lockbitmap "mpx-lock"
    } else {
	set lockbitmap "mpx-unlock"
    }
    $w.locktools config -bitmap @$bitmapdir/$lockbitmap

    set newmode [ PxGet $prop OperatingMode $toolbox($w,opmode)  ]

    if { $newmode != $toolbox($w,opmode) } {
	set toolbox($w,opmode) $newmode
        if {$newmode == "ThreeD" || $newmode == "AllVolumes" }  {
	    if { $newmode == "ThreeD" } {
		set bitmapfn "my-3d"
	    } else {
		set bitmapfn "my-3dall"
	    }
	    pack forget $w.icons2d
	    pack forget $w.ff
	    pack $w.icons3d -in $w.if 

	    # change to Spatial 3D
	    set m $w.transformation.menu 
	    Toolbox:menupdate $m "Spatial*" {-label "Spatial (3D)..." \
		-command {Message:PostDialog .spatial3d}}
	    # enable resample
	    Toolbox:menupdate $m "Resample*" {-state normal}
	    # enable flip volume
	    Toolbox:menupdate $m "Flip*" {-state normal}

	    # disable blend
	    Toolbox:menupdate $w.fusion.menu "Blend*" {-state disabled}

	    # disable warp, enable talairach
	    set m $w.registration.menu
	    Toolbox:menupdate $m "Warp*" {-state disabled}
	    Toolbox:menupdate $m "Talairach*" {-state normal}

	    # disable colorspace conversion and compose triband
	    Toolbox:menupdate $w.conversion.menu "*Conversion*" {-state disabled}
	    Toolbox:menupdate $w.conversion.menu "*Triband*" {-state disabled}

	    # enable skull stripping
	    Toolbox:menupdate $w.segmentation.menu "Interactive*" \
		{-state normal}
	} else {
	    pack forget $w.icons3d
	    pack $w.icons2d -in $w.if 
	    pack $w.ff -in $w.hf -side top -expand yes -fill both
	    if { $toolbox($w,opmode) == "AllSlices"} {
		set bitmapfn "my-2dall"
	    } else {
		set bitmapfn "my-2d"
	    }

	    # change to Spatial 2D
	    set m $w.transformation.menu 
	    Toolbox:menupdate $m "Spatial*" {-label "Spatial (2D)..." \
		-command {Message:PostDialog .spatial2d}}
	    # disable resample
	    Toolbox:menupdate $m "Resample*" {-state disabled}
	    # disable flip
	    Toolbox:menupdate $m "Flip*" {-state disabled}

	    # enable blend
	    Toolbox:menupdate $w.fusion.menu "Blend*" {-state normal}

	    # enable warp, disable talairach
	    set m $w.registration.menu
	    Toolbox:menupdate $m "Warp*" {-state normal}
	    Toolbox:menupdate $m "Talairach*" {-state disabled}

	    # enable colorspace conversion
	    Toolbox:menupdate $w.conversion.menu "*Conversion*" {-state normal}
	    Toolbox:menupdate $w.conversion.menu "*Triband*" {-state normal}

	    # enable skull stripping
	    Toolbox:menupdate $w.segmentation.menu "Interactive*" \
		{-state disabled}

	}
	$w.dimensions config -bitmap @$bitmapdir/$bitmapfn
    }
    set newmode [ PxGet $prop InteractiveMode $toolbox($w,imode) ]
    set toolbox($w,imode) $newmode
    
    switch -exact $newmode {
	AngleTool         { settool $w angle       none }
	ArrowTool         { settool $w arrow       none }
	BitmapEditTool    { settool $w bitmap      bitmap }
	ButtonTool        { settool $w button      none }
	CircleTool        { settool $w ellipse     none }
	EdgeTool          { settool $w edge        none }
	EraserTool        { settool $w erase       none }
	LineTool          { settool $w line        none }
	MarkerTool        { settool $w marker      marker3d }
	PencilTool        { settool $w pencil      none }
	PixelTool         { settool $w pixelreport pixelreport }
	PointTool         { settool $w point       point }
	PolyEditTool      { settool $w arbitrary     none }
	PolyTool          { settool $w polygon     none }
	RectangleTool     { settool $w rectangle   none }
	RotateGraphicTool { settool $w rotate      none }
	TextTool          { settool $w text        none }

	BoxTool           { settool $w none        box }
	EllipsoidTool     { settool $w none        ellipsoid }
	Line3DTool        { settool $w none        line3d }
	Angle3DTool       { settool $w none        angle3d }
	Marker3DTool      { settool $w marker      marker3d }
	Poly3DTool        { settool $w none        contour }
    }

}

proc settool { w twod threed } {

    if { $twod != "none" } {
	$w.icons2d configure -disablecallback true
	$w.icons2d configure -value $twod
	$w.icons2d configure -disablecallback false
    }
    if { $threed != "none" } {
	$w.icons3d configure -disablecallback true
	$w.icons3d configure -value $threed
	$w.icons3d configure -disablecallback false
    }
}


# Procedure:	Toolbox:skullstrip
#
# Usage:	Toolbox:skullstrip widget
#
# Summary:	
#
proc Toolbox:skullstrip { } {

    Message:OnFunctionCompletion SetView {
	Message:InvokeFunction OrthoSegmentationViewer
    }
    Message:InvokeFunction SetView "View OrthogonalView"
}
    
# This "if" statement makes it possible to run this script file inside or
# outside of the main demo program "phase?".
#
#if {![info exists phase_demo_running]} {
#    lappend auto_path ../
#    wm withdraw .
#    set bitmapdir ../bitmaps
#    set remote_out stdout
#    Toolbox .tb1
#}

