#   fsl - meta-menu for fsl tools
#
#   Stephen Smith, FMRIB Image Analysis Group
#
#   Copyright (C) 1999-2001 University of Oxford
#
#   Part of FSL - FMRIB's Software Library
#   http://www.fmrib.ox.ac.uk/fsl
#   fsl@fmrib.ox.ac.uk
#   
#   Developed at FMRIB (Oxford Centre for Functional Magnetic Resonance
#   Imaging of the Brain), Department of Clinical Neurology, Oxford
#   University, Oxford, UK
#   
#   
#   LICENCE
#   
#   FMRIB Software Library, Release 3.0 (c) 2002, The University of Oxford
#   (the "Software")
#   
#   The Software remains the property of the University of Oxford ("the
#   University").
#   
#   The Software is distributed "AS IS" under this Licence solely for
#   non-commercial use in the hope that it will be useful, but in order
#   that the University as a charitable foundation protects its assets for
#   the benefit of its educational and research purposes, the University
#   makes clear that no condition is made or to be implied, nor is any
#   warranty given or to be implied, as to the accuracy of the Software,
#   or that it will be suitable for any particular purpose or for use
#   under any specific conditions. Furthermore, the University disclaims
#   all responsibility for the use which is made of the Software. It
#   further disclaims any liability for the outcomes arising from using
#   the Software.
#   
#   The Licensee agrees to indemnify the University and hold the
#   University harmless from and against any and all claims, damages and
#   liabilities asserted by third parties (including claims for
#   negligence) which arise directly or indirectly from the use of the
#   Software or the sale of any products based on the Software.
#   
#   No part of the Software may be reproduced, modified, transmitted or
#   transferred in any form or by any means, electronic or mechanical,
#   without the express permission of the University. The permission of
#   the University is not required if the said reproduction, modification,
#   transmission or transference is done without financial return, the
#   conditions of this Licence are imposed upon the receiver of the
#   product, and all original and amended source code is included in any
#   transmitted product. You may be held legally responsible for any
#   copyright infringement that is caused or encouraged by your failure to
#   abide by these terms and conditions.
#   
#   You are not permitted under this Licence to use this Software
#   commercially. Use for which any financial return is received shall be
#   defined as commercial use, and includes (1) integration of all or part
#   of the source code or the Software into a product for sale or license
#   by or on behalf of Licensee to third parties or (2) use of the
#   Software or any derivative of it for research with the final aim of
#   developing software products for sale or license to a third party or
#   (3) use of the Software or any derivative of it for research with the
#   final aim of developing non-software products for sale or license to a
#   third party, or (4) use of the Software to provide any service to an
#   external organisation for which payment is received. If you are
#   interested in using the Software commercially, please contact Isis
#   Innovation Limited ("Isis"), the technology transfer company of the
#   University, to negotiate a licence. Contact details are:
#   innovation@isis.ox.ac.uk quoting reference DE/1112.

#{{{ setups

source [ file dirname [ info script ] ]/fslstart.tcl

set VARS(history) {}

#}}}

proc fsl { w } {

    #{{{ vars and setup

global FSLDIR INMEDX argc argv PWD HOME gui_ext

set FSLVERSION [ exec cat ${FSLDIR}/etc/fslversion ]

toplevel $w -menu $w.f1.fmrib.menu
wm title $w "FSL $FSLVERSION"
wm iconname $w "FSL"
wm iconbitmap $w @${FSLDIR}/tcl/fmrib.xbm

set graphpic [image create photo -file ${FSLDIR}/doc/images/fsl-logo.gif ]

frame $w.f1

button $w.f1.label -image $graphpic -borderwidth 0 \
	-command "FmribWebHelp file: ${FSLDIR}/doc/index.html" \

set BW 19

#}}}
    #{{{ main menu

pack $w.f1.label -in $w.f1

if { [ file exists ${FSLDIR}/tcl/loadvarian.tcl ] } {
    button $w.f1.loadvarian -text "Load Varian" -width $BW \
	    -command { exec ${FSLDIR}/bin/LoadVarian$gui_ext & }
    pack $w.f1.loadvarian -in $w.f1
}

if { [ file exists ${FSLDIR}/tcl/bet.tcl ] } {
    button $w.f1.bet -text "BET Brain Extraction" -width $BW \
	    -command { exec ${FSLDIR}/bin/Bet$gui_ext & }
    pack $w.f1.bet -in $w.f1
}

if { [ file exists ${FSLDIR}/tcl/susan.tcl ] } {
    button $w.f1.susan -text "SUSAN Noise Reduction" -width $BW \
	    -command { exec ${FSLDIR}/bin/Susan$gui_ext & }
    pack $w.f1.susan -in $w.f1
}

if { [ file exists ${FSLDIR}/tcl/fast.tcl ] } {
    button $w.f1.fast -text "FAST Segmentation" -width $BW \
	    -command { exec ${FSLDIR}/bin/Fast$gui_ext & }
    pack $w.f1.fast -in $w.f1
}

if { [ file exists ${FSLDIR}/tcl/flirt.tcl ] } {
    button $w.f1.flirt -text "FLIRT Linear Registration" -width $BW \
	    -command { exec ${FSLDIR}/bin/Flirt$gui_ext & }
    pack $w.f1.flirt -in $w.f1
}

if { [ file exists ${FSLDIR}/tcl/feat.tcl ] } {
    button $w.f1.feat -text "FEAT FMRI Analysis" -width $BW \
	    -command { exec ${FSLDIR}/bin/Feat$gui_ext & }
    pack $w.f1.feat -in $w.f1
}

if { [ file exists ${FSLDIR}/tcl/melodic.tcl ] } {
    button $w.f1.melodic -text "MELODIC ICA" -width $BW \
	    -command { exec ${FSLDIR}/bin/Melodic$gui_ext & }
    pack $w.f1.melodic -in $w.f1
}

#}}}
    #{{{ Button Frame

    frame $w.btns
    frame $w.btns.b -relief raised -borderwidth 1
 
    button $w.cancel    -command "destroy $w" \
        -text "Exit" -width 5
    bind $w.cancel <Return> {
        [winfo toplevel %W].cancel invoke}
 
    button $w.help -command "FmribWebHelp file: ${FSLDIR}/doc/index.html" \
            -text "Help" -width 5
    bind $w.help <Return> {
        [winfo toplevel %W].help invoke}

    pack $w.btns.b -side bottom -fill x
    pack $w.cancel $w.help -in $w.btns.b \
        -side left -expand yes -padx 3 -pady 3 -fill y
 
    pack $w.f1 $w.btns -expand yes -fill both

#}}}
}

wm withdraw .
fsl .rename
tkwait window .rename
