#

#   mask - convert image to MINC and run Display and the reread image
#
#   Stephen Smith, FMRIB Image Analysis Group
#
#   Copyright (C) 1999-2000 University of Oxford
#
#   Part of FSL - FMRIB's Software Library
#   http://www.fmrib.ox.ac.uk/fsl
#   fsl@fmrib.ox.ac.uk
#   
#   Developed at FMRIB (Oxford Centre for Functional Magnetic Resonance
#   Imaging of the Brain), Department of Clinical Neurology, Oxford
#   University, Oxford, UK
#   
#   
#   LICENCE
#   
#   FMRIB Software Library, Release 3.0 (c) 2002, The University of Oxford
#   (the "Software")
#   
#   The Software remains the property of the University of Oxford ("the
#   University").
#   
#   The Software is distributed "AS IS" under this Licence solely for
#   non-commercial use in the hope that it will be useful, but in order
#   that the University as a charitable foundation protects its assets for
#   the benefit of its educational and research purposes, the University
#   makes clear that no condition is made or to be implied, nor is any
#   warranty given or to be implied, as to the accuracy of the Software,
#   or that it will be suitable for any particular purpose or for use
#   under any specific conditions. Furthermore, the University disclaims
#   all responsibility for the use which is made of the Software. It
#   further disclaims any liability for the outcomes arising from using
#   the Software.
#   
#   The Licensee agrees to indemnify the University and hold the
#   University harmless from and against any and all claims, damages and
#   liabilities asserted by third parties (including claims for
#   negligence) which arise directly or indirectly from the use of the
#   Software or the sale of any products based on the Software.
#   
#   No part of the Software may be reproduced, modified, transmitted or
#   transferred in any form or by any means, electronic or mechanical,
#   without the express permission of the University. The permission of
#   the University is not required if the said reproduction, modification,
#   transmission or transference is done without financial return, the
#   conditions of this Licence are imposed upon the receiver of the
#   product, and all original and amended source code is included in any
#   transmitted product. You may be held legally responsible for any
#   copyright infringement that is caused or encouraged by your failure to
#   abide by these terms and conditions.
#   
#   You are not permitted under this Licence to use this Software
#   commercially. Use for which any financial return is received shall be
#   defined as commercial use, and includes (1) integration of all or part
#   of the source code or the Software into a product for sale or license
#   by or on behalf of Licensee to third parties or (2) use of the
#   Software or any derivative of it for research with the final aim of
#   developing software products for sale or license to a third party or
#   (3) use of the Software or any derivative of it for research with the
#   final aim of developing non-software products for sale or license to a
#   third party, or (4) use of the Software to provide any service to an
#   external organisation for which payment is received. If you are
#   interested in using the Software commercially, please contact Isis
#   Innovation Limited ("Isis"), the technology transfer company of the
#   University, to negotiate a licence. Contact details are:
#   innovation@isis.ox.ac.uk quoting reference DE/1112.

if { [ info exists env(FSLDIR) ] } {
    set FSLDIR $env(FSLDIR)
} else {
    set FSLDIR $PXHOME/fsl
}

source ${FSLDIR}/tcl/medxstart.tcl
set auto_path [ linsert $auto_path 0 [ file dirname [ info script ] ] ]

proc mni_mask {Folder In TheArgs} {
    global PXHOME USER PROCID exceed

# save image to temp AVW file
FSLSaveAs $In AVW /tmp/${USER}_${PROCID}_mask.hdr true

# convert to minc
set thecommand "exec /usr/local/mni/bin/analyze2minc /tmp/${USER}_${PROCID}_mask"
ScriptUpdate "Converting to MINC format: $thecommand"
set result [catch {eval $thecommand} ErrMsg]

# run external program
set thecommand "exec xterm -e /usr/local/mni/bin/Display /tmp/${USER}_${PROCID}_mask.mnc &"
set result [catch {eval $thecommand} ErrMsg]

after 5000
after 5000
MxPause "Now create a coloured mask in the \"Display\" program from Montreal. DO NOT CHANGE THE DEFAULT LABEL COLOUR/VALUE! Use right-mouse to draw mask points and shift-right-mouse to delete mask points. Use left- and middle-mouse to move around in the image. To change the mask drawing cursor size click (in the menu window) \"Segmenting\", then \"XY Radius\", and enter the value in the XTerm, and finally press \"Pop Menu\". When you are finished, save the mask to file using (in the menu window) \"File\", then \"Save Labels .mnc\" and enter the following filename in the XTerm and press return: /tmp/${PROCID}.mnc then you can exit \"Display\"\n\nWhen you are finished press OK"

# convert to minc
set thecommand "exec /usr/local/mni/bin/mincresample /tmp/${PROCID}.mnc /tmp/${USER}_${PROCID}_label.mnc -like /tmp/${USER}_${PROCID}_mask.mnc"
ScriptUpdate "Converting to AVW format 1/2: $thecommand"
set result [catch {eval $thecommand} ErrMsg]
set thecommand "exec /usr/local/mni/bin/minc2analyze /tmp/${USER}_${PROCID}_label"
ScriptUpdate "Converting to AVW format 2/2: $thecommand"
set result [catch {eval $thecommand} ErrMsg]

MxOpenImage $Folder /tmp/${USER}_${PROCID}_label.hdr I1
MxSetCurrentPage $I1

}
