#

# Copyright (C) 1998 John O'Doherty
# Dept. of Exp. Psy., Oxford. E-mail:john.odoherty@psy.ox.ac.uk
# Plus a few alterations, Steve Smith

#   Part of FSL - FMRIB's Software Library
#   http://www.fmrib.ox.ac.uk/fsl
#   fsl@fmrib.ox.ac.uk
#   
#   Developed at FMRIB (Oxford Centre for Functional Magnetic Resonance
#   Imaging of the Brain), Department of Clinical Neurology, Oxford
#   University, Oxford, UK
#   
#   
#   LICENCE
#   
#   FMRIB Software Library, Release 3.0 (c) 2002, The University of Oxford
#   (the "Software")
#   
#   The Software remains the property of the University of Oxford ("the
#   University").
#   
#   The Software is distributed "AS IS" under this Licence solely for
#   non-commercial use in the hope that it will be useful, but in order
#   that the University as a charitable foundation protects its assets for
#   the benefit of its educational and research purposes, the University
#   makes clear that no condition is made or to be implied, nor is any
#   warranty given or to be implied, as to the accuracy of the Software,
#   or that it will be suitable for any particular purpose or for use
#   under any specific conditions. Furthermore, the University disclaims
#   all responsibility for the use which is made of the Software. It
#   further disclaims any liability for the outcomes arising from using
#   the Software.
#   
#   The Licensee agrees to indemnify the University and hold the
#   University harmless from and against any and all claims, damages and
#   liabilities asserted by third parties (including claims for
#   negligence) which arise directly or indirectly from the use of the
#   Software or the sale of any products based on the Software.
#   
#   No part of the Software may be reproduced, modified, transmitted or
#   transferred in any form or by any means, electronic or mechanical,
#   without the express permission of the University. The permission of
#   the University is not required if the said reproduction, modification,
#   transmission or transference is done without financial return, the
#   conditions of this Licence are imposed upon the receiver of the
#   product, and all original and amended source code is included in any
#   transmitted product. You may be held legally responsible for any
#   copyright infringement that is caused or encouraged by your failure to
#   abide by these terms and conditions.
#   
#   You are not permitted under this Licence to use this Software
#   commercially. Use for which any financial return is received shall be
#   defined as commercial use, and includes (1) integration of all or part
#   of the source code or the Software into a product for sale or license
#   by or on behalf of Licensee to third parties or (2) use of the
#   Software or any derivative of it for research with the final aim of
#   developing software products for sale or license to a third party or
#   (3) use of the Software or any derivative of it for research with the
#   final aim of developing non-software products for sale or license to a
#   third party, or (4) use of the Software to provide any service to an
#   external organisation for which payment is received. If you are
#   interested in using the Software commercially, please contact Isis
#   Innovation Limited ("Isis"), the technology transfer company of the
#   University, to negotiate a licence. Contact details are:
#   innovation@isis.ox.ac.uk quoting reference DE/1112.

if { [ info exists env(FSLDIR) ] } {
    set FSLDIR $env(FSLDIR)
} else {
    set FSLDIR $PXHOME/fsl
}

source ${FSLDIR}/tcl/medxstart.tcl
set auto_path [ linsert $auto_path 0 [ file dirname [ info script ] ] ]

set on "onvol"
set off "offvols"
set colon ":"
set imagelist ""
set orderon 0
set orderoff 0

#enter number of files
InputFromWidget "Serial T-test" 6 "Initial offset" initialoffset 6 "Size of ON period" onsize 6 "Size of OFF period" offsize 6 "# images for comparison from ON period" nofromon 6  "offset in OFF period" offset 6 "# images for comparison from OFF period" nofromoff 6 

set reply [YesNoWidget "Start with ON or OFF groups?"  ON OFF]
if {$reply==0} {
set orderoff $onsize
set orderon  $offsize
}

MxGetCurrentFolder folder
MxGetCurrentGroup group
MxGetPagesFromGroup $Group Pages
set totnum 0
foreach Page $Pages {
incr totnum 1
}

set cyclen  [expr $onsize+$offsize]
set channel [open "/tmp/${USER}stt.pdm" "w"] 

puts $channel "%!VEST-ParadigmFile"
puts $channel "#groups"

#identify on groups
for {set i 1} {$i <= [expr ($onsize - $nofromon + 1)]} {incr i 1} {
puts $channel $on$i
}
#add off group
puts $channel "offvols"
puts $channel "All"

#add group colours
puts $channel "# group colours"
for {set i 1} {$i <= [expr ($onsize - $nofromon + 1)]} {incr i 1} {
puts $channel "$on$i red"
}
puts $channel "offvols blue"
puts $channel "All    black"

#set out time points
puts $channel "# time points"

for {set n $initialoffset} {$n < $totnum} {incr n $cyclen} {

     for {set groupno 1} {$groupno <= [expr ($onsize - $nofromon + 1)]} {incr groupno 1} {
       set on_start [expr $groupno + $n + $orderon]
       set on_finish [expr $on_start + $nofromon - 1]
       if { $on_finish <= $totnum } {
         set outon "$on_start$colon$on_finish     onvol$groupno"
         #Add ALL to non-overlapping groups
         if ([expr $on_start % $nofromon]==1) {
         append outon "    All"
         }
         puts $channel  $outon
       }       
     }
 set off_start [expr $n + $onsize + $offset-$orderoff + 1]
 set off_finish [expr $off_start + $nofromoff - 1]
 if { $on_finish <= $totnum } {
   set outoff "$off_start$colon$off_finish   offvols       All"
   puts $channel $outoff    
 }
 }
       
close $channel

#load the new paradigm file
MxApplyParadigmGrouping $group "/tmp/${USER}stt.pdm"  resultgroups
MxGetPageByName $folder $off offp

#then go through and perform serial t-tests
for {set i 1} {$i <= [expr ($onsize - $nofromon + 1)]} {incr i 1} {
MxGetPageByName $folder $on$i onp 
MxBetweenGrpStatistics $onp $offp U I0 I1 I2 I3 I4
append imagelist $I3 " "
}

MxGroupImages $imagelist I "Serial T-Test:z-maps" I5
